summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/vcf
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/vcf')
-rw-r--r--kfile-plugins/vcf/kfile_vcf.cpp28
-rw-r--r--kfile-plugins/vcf/kfile_vcf.h2
2 files changed, 15 insertions, 15 deletions
diff --git a/kfile-plugins/vcf/kfile_vcf.h b/kfile-plugins/vcf/kfile_vcf.h
index a0b147c6..3bd75fb4 100644
--- a/kfile-plugins/vcf/kfile_vcf.h
+++ b/kfile-plugins/vcf/kfile_vcf.h
@@ -29,7 +29,7 @@ class KVcfPlugin: public KFilePlugin
Q_OBJECT
public:
- KVcfPlugin( QObject *parent, const char *name, const QStringList& args );
+ KVcfPlugin( TQObject *parent, const char *name, const TQStringList& args );
virtual bool readInfo( KFileMetaInfo& info, uint what);
};
diff --git a/kfile-plugins/vcf/kfile_vcf.cpp b/kfile-plugins/vcf/kfile_vcf.cpp
index f9440f6d..76b3383c 100644
--- a/kfile-plugins/vcf/kfile_vcf.cpp
+++ b/kfile-plugins/vcf/kfile_vcf.cpp
@@ -26,15 +26,15 @@
#include <kgenericfactory.h>
#include <kabc/vcardconverter.h>
-#include <qdict.h>
-#include <qfile.h>
+#include <tqdict.h>
+#include <tqfile.h>
typedef KGenericFactory<KVcfPlugin> VcfFactory;
K_EXPORT_COMPONENT_FACTORY(kfile_vcf, VcfFactory( "kfile_vcf" ))
-KVcfPlugin::KVcfPlugin(QObject *parent, const char *name,
- const QStringList &args)
+KVcfPlugin::KVcfPlugin(TQObject *parent, const char *name,
+ const TQStringList &args)
: KFilePlugin(parent, name, args)
{
@@ -46,25 +46,25 @@ KVcfPlugin::KVcfPlugin(QObject *parent, const char *name,
KFileMimeTypeInfo::ItemInfo* item;
- item = addItemInfo(group, "Name", i18n("Name"), QVariant::String);
- item = addItemInfo(group, "Email", i18n("Email"), QVariant::String);
- item = addItemInfo(group, "Telephone", i18n("Telephone"), QVariant::String);
+ item = addItemInfo(group, "Name", i18n("Name"), TQVariant::String);
+ item = addItemInfo(group, "Email", i18n("Email"), TQVariant::String);
+ item = addItemInfo(group, "Telephone", i18n("Telephone"), TQVariant::String);
}
bool KVcfPlugin::readInfo( KFileMetaInfo& info, uint /*what*/ )
{
- QFile file(info.path());
+ TQFile file(info.path());
if (!file.open(IO_ReadOnly))
{
- kdDebug(7034) << "Couldn't open " << QFile::encodeName(info.path()) << endl;
+ kdDebug(7034) << "Couldn't open " << TQFile::encodeName(info.path()) << endl;
return false;
}
// even the vcard thumbnail QString::fromUtf8(buf_name));creator reads the full file ...
// The following is partly copied from there
- QString contents = file.readAll();
+ TQString contents = file.readAll();
file.close();
KABC::VCardConverter converter;
@@ -73,7 +73,7 @@ bool KVcfPlugin::readInfo( KFileMetaInfo& info, uint /*what*/ )
KFileMetaInfoGroup group = appendGroup(info, "Technical");
// prepare the text
- QString name = addr.formattedName().simplifyWhiteSpace();
+ TQString name = addr.formattedName().simplifyWhiteSpace();
if ( name.isEmpty() )
name = addr.givenName() + " " + addr.familyName();
name = name.simplifyWhiteSpace();
@@ -85,9 +85,9 @@ bool KVcfPlugin::readInfo( KFileMetaInfo& info, uint /*what*/ )
appendItem(group, "Email", addr.preferredEmail());
KABC::PhoneNumber::List pnList = addr.phoneNumbers();
- QStringList phoneNumbers;
+ TQStringList phoneNumbers;
for (unsigned int no=0; no<pnList.count(); ++no) {
- QString pn = pnList[no].number().simplifyWhiteSpace();
+ TQString pn = pnList[no].number().simplifyWhiteSpace();
if (!pn.isEmpty() && !phoneNumbers.contains(pn))
phoneNumbers.append(pn);
}
@@ -46,25 +46,25 @@ KVcfPlugin::KVcfPlugin(QObject *parent, const char *name,
return false;
}
- // even the vcard thumbnail QString::fromUtf8(buf_name));creator reads the full file ...
+ // even the vcard thumbnail TQString::fromUtf8(buf_name));creator reads the full file ...
// The following is partly copied from there